@@ -4,16 +4,16 @@ export const chapterTemplate = ({part, contents}) => `
     ${
     part && part.length ?
         `<h1 class="part">${escapeText(part)}</h1>` :
-        ''
+        ""
 }
     ${contents}`
 
-export const printHTMLTemplate = ({css, html, title}) => `<!DOCTYPE html>
-<html>
+export const printHTMLTemplate = ({css, html, title, settings}) => `<!DOCTYPE html>
+<html lang="${settings.language.split("-")[0]}">
     <head>
         <meta charset="UTF-8">
         <title>${title}</title>
-        <link type="text/css" rel="stylesheet" href="${settings_STATIC_URL}css/book.css?v=${transpile_VERSION}" />
+        <link type="text/css" rel="stylesheet" href="${staticUrl("css/book.css")}" />
         <style>
             ${css}
         </style>
